// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho...  2 febrero 2016
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// RFTC RefrigeradoraFriaTiempoCompleto
// El archivo dibuja una refrigeradora de uso domestico.
// Es muy poco flexible, pero incluye una macro para modificar 
// algunas de sus caracteristicas principales.
// Es compatible con POVRay 3.1.
//
// La macro principal tiene unicamente dos parametros  
// #macro RFTC_Refrigeradora( AnguloPuerta, AnguloHielera )
//      AnguloPuerta            : Angulo para abrir la puerta principal.
//      AnguloHielera           : Angulo para abrir puerta del congelador.
//
// La siguiente macro permite un mayor control de las caracteristicas.
// #macro RFTC_RefrigeradoraFriaTiempoCompleto( AnguloPuerta, AnguloHielera,
//                AltoFundamental, FrenteFundamental, ProfundidadFundamnetal,
//                AlturaHielera, PrimerMarco, AlturaSeparadoresNivel,
//                MarcoAislanteMenor, MarcoAislanteMayor,
//                BasePiso, GruesoDivisiones, GruesoPlastico,
//                EspacioInteriorPuerta, GruesoPuerta,
//                ArregloTexturas )
//      AnguloPuerta            : Angulo para abrir la puerta principal.
//      AnguloHielera           : Angulo para abrir puerta del congelador.
//      AltoFundamental         : Alto total de la refrigeradora. Valor
//              por defecto 1135*L;
//      FrenteFundamental       : Referencia para el frente X de la refrigeradora.
//              Valor por defecto 480*L.
//      ProfundidadFundamental  : Referencia para la profundidad Z del aparato.
//              Valor por defecto 390*L;
//      AlturaHielera           : Altura asignada a la hielera.
//              Valor por defecto 350*L;
//      PrimerMarco             : Marco metalico de la refrigeradora, parcialmente visible
//              al exterior. Valor por defecto 15*L;
//      AlturaSeparadoresNivel  : Dimension Y de la separacion principal con la hielera
//              y el piso. Valor por defecto 25*L.
//      MarcoAislanteMenor      : Valor por defecto del grueso de aislamiento termico
//              en su capa delgada. Valor por defecto 18*L.
//      MarcoAislanteMayor      : Valor por defecto del grueso de aislamiento termico
//              en su capa gruesa. Valor por defecto 43*L.
//      BasePiso                : Altura de las patas. Valor por defecto 25*L.
//      GruesoDivisiones        : Dimension Y de las divisiones internas.
//              Valor por defecto 7*L;
//      GruesoPlastico          : Grueso fundamental del material plastico.
//              Valor por defecto 2*L.
//      EspacioInteriorPuerta   : Referencia del espacio interno reservado para la puerta.
//              Valor por defecto 86*L.
//      GruesoPuerta            : Referencia para el grueso de la puerta eliminando curvatura.
//              Valor por defecto 40*L.  
//      ArregloTexturas         : Arreglo de 7 o mas texturas, que se aplicaran en la figura.
//              Se utilizaran unicamente las primeras siete:
//              { Lateral, Aislante, NivelInterior, Puerta, Hule, Enfriamiento, Gavetilla },
//              Para redefinir la textura se recomienda utilizar los siguientes indices,
//              con el objetivo de facilitar compatibilidad futura. Los indices
//              son los numeros del 0 al 6 en forma ascendente.
//                      RFTC_IndiceTexturaLateral       : Paredes laterales.
//                      RFTC_IndiceTexturaAislante      : Interior del refrigerador.
//                      RFTC_IndiceTexturaNivelInterior : Vidrio en las divisiones internas.
//                      RFTC_IndiceTexturaPuerta        : Principal de la puerta.
//                      RFTC_IndiceTexturaHule          : Hule entre la puerta y el refrigerador.
//                      RFTC_IndiceTexturaEnfriamiento  : Tuberia de enfriamiento exterior.
//                      RFTC_IndiceTexturaGavetilla     : Gavetilla para las verduras y 
//                                  otras en la puerta.
//
// La refrigeradora se encuentra completamente contenida dentro de las siguientes coordenadas.
//      Minimo  = < -255,    0,    0 >*L
//      Maximo  = <  245, 1135, -520 >*L
// Frente hacia Z-, gravedad hacia Y-. Piso en plano XZ, y probable pared en plano XY.
// El eje Y+ sirve como guia para casi centrar la estructura completa en su parte posterior.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiar sus efectos, recurra a los modificadores.  
// #declare RFTC_TotalTexturas                      = 7; 
//      Total de texturas minimo para el parametro ArregloTexturas.      
// #declare RFTC_DefaultTexturaLateral  
//      Textura para las paredes laterales. 
// #declare RFTC_DefaultTexturaAislante      
//      Textura para el interior del refrigerador.
// #declare RFTC_DefaultTexturaNivelInterior            
//      Textura para el vidrio de las separaciones internas.
// #declare RFTC_DefaultTexturaPuerta       
//      Textura principal para aplicar a la puerta.
// #declare RFTC_DefaultTexturHule
//      Textura para el hule que separa y protege la refrigeradora de la puerta.
// #declare RFTC_DefaultTexturaEnfriamiento             
//      Textura para los tubos de enfriamiento.   
// #declare RFTC_DefaultTexturaGavetilla            
//      Textura de la gavetilla para vegetales y otras de la puerta.  
// #declare RFTC_ArregloTexturas            
//      Arreglo que contiene las siete texturas. Puede ser utilizada como parametro.
//      No se afecta por los modificadores, si la modificacion es posterior a la inclusion
//      del archivo.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare RFTC_TexturaLateral               = texture { ... } 
//      Textura para las paredes laterales. 
// #declare RFTC_TexturaAislante              = texture { ... }
//      Textura para el interior del refrigerador.
// #declare RFTC_TexturaNivelInterior         = texture { ... }   
//      Textura para el vidrio de las separaciones internas.
// #declare RFTC_TexturaPuerta                = texture { ... }
//      Textura principal para aplicar a la puerta.
// #declare RFTC_TexturaHule                  = texture { ... }
//      Textura para el hule que separa y protege la refrigeradora de la puerta.
// #declare RFTC_TexturaEnfriamiento          = texture { ... }  
//      Textura para los tubos de enfriamiento.   
// #declare RFTC_TexturaGavetilla             = texture { ... }
//      Textura de la gavetilla para vegetales y otras de la puerta.  
//
// Para colocarlo simplemente
// #include "RFTC.inc"
// object        { RFTC_Refrigeradora( 0, 0 ) }
//                           
// Ejemplo con la macro detallada, mismo objeto default
// #include "RFTC.inc"   
// object                       {
//   RFTC_RefrigeradoraFriaTiempoCompleto( 0, 0, 
//            1.135, 0.480, 0.390, 0.350, 0.015,
//            0.025, 0.018, 0.043, 0.025, 0.007, 
//            0.002, 0.086, 0.040, RFTC_ArregloTexturas )
// }
//                                                     
// Puede declarar su propio arreglo de texturas.
// #include "RFTC.inc"   
// #declare ArregloTexturas   = array [7]
//      { PinkAlabaster, PinkAlabaster, PinkAlabaster, PinkAlabaster,
//        PinkAlabaster, PinkAlabaster, PinkAlabaster }
// object                       {
//   RFTC_RefrigeradoraFriaTiempoCompleto( 0, 0, 
//            1.135, 0.480, 0.390, 0.350, 0.015,
//            0.025, 0.018, 0.043, 0.025, 0.007, 
//            0.002, 0.086, 0.040, ArregloTexturas )
// }
//
// Con modificadores
// #include "RFTC.inc"
// #include "textures.inc"
// #declare RFTC_TexturaLateral   = PinkAlabaster
// object        { RFTC_Cocina( 0, 0 ) }
// 
#if ( version >= 3.7 ) 
#version 3.7;
#end         
// POVRay 3.7 solicita el numero de version en el primer renglon ejecutable.
// En el futuro podria ser necesario eliminar el comentario #if ... #end   
global_settings   { assumed_gamma 1.0 }

#include "colors.inc"

#declare OjoAbsoluto            = 256;
#declare VecesCentroAbsoluto    = 10;     
#declare L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         

light_source    {
         < 500  , 500   , -3000 >*L
         White
}
background      {
         Gray50
}    

#include "RFTC.inc"

#local FactorAcercamiento       = 0.875;                                   
                                   
object                  {
  RFTC_Refrigeradora( 130, 90 )    
  translate         -0.565*y  
  translate       -( VecesCentroAbsoluto+1 )*( FactorAcercamiento-1 )
                        /( FactorAcercamiento )*OjoAbsoluto*L*z      
}
